@@ -6,7 +6,7 @@ JSON::Validator - Validate data against a JSON schema
 
 =head1 VERSION
 
-0.58
+0.59
 
 =head1 SYNOPSIS
 
@@ -64,8 +64,6 @@ Here are some resources that are related to JSON schemas and validation:
 
 =item * L<http://spacetelescope.github.io/understanding-json-schema/index.html>
 
-=item * L<http://jsonary.com/documentation/json-schema/>
-
 =item * L<https://github.com/json-schema/json-schema/>
 
 =item * L<Swagger2>
@@ -142,7 +140,7 @@ use constant DEBUG => $ENV{JSON_VALIDATOR_DEBUG} || $ENV{SWAGGER2_DEBUG} || 0;
 use constant WARN_ON_MISSING_FORMAT => $ENV{JSON_VALIDATOR_WARN_ON_MISSING_FORMAT}
   || $ENV{SWAGGER2_WARN_ON_MISSING_FORMAT} ? 1 : 0;
 
-our $VERSION = '0.58';
+our $VERSION = '0.59';
 our @EXPORT_OK = qw( validate_json );
 
 my $HTTP_SCHEME_RE = qr{^https?:};
@@ -382,16 +380,6 @@ sub _build_formats {
   };
 }
 
-sub _coerce_by_collection_format {
-  my ($self, $schema, $data) = @_;
-  my $format = $schema->{collectionFormat};
-  my @data = $format eq 'ssv' ? split / /, $data : $format eq 'tsv' ? split /\t/,
-    $data : $format eq 'pipes' ? split /\|/, $data : split /,/, $data;
-
-  return [map { $_ + 0 } @data] if $schema->{type} and $schema->{type} =~ m!^(integer|number)$!;
-  return \@data;
-}
-
 sub _load_schema {
   my ($self, $url, $parent) = @_;
   my ($namespace, $scheme) = ("$url", "file");
@@ -700,15 +688,9 @@ sub _validate_type_array {
   my ($self, $data, $path, $schema) = @_;
   my @errors;
 
-  if (ref $schema->{items} eq 'HASH' and $schema->{items}{collectionFormat}) {
-    $data = $self->_coerce_by_collection_format($schema->{items}, $data);
-  }
   if (ref $data ne 'ARRAY') {
     return E $path, _expected(array => $data);
   }
-
-  $data = [@$data];
-
   if (defined $schema->{minItems} and $schema->{minItems} > @$data) {
     push @errors, E $path, sprintf 'Not enough items: %s/%s.', int @$data, $schema->{minItems};
   }
